@@ -36,11 +36,12 @@ namespace Beagle.Filters {
 	public class FilterC : FilterSource {
 
 		static string  [] strKeyWords  = {"auto", "break", "case", "char", "const", 
-						"continue", "default", "do", "double", "else",
-						"enum", "extern", "float", "for", "goto",
-						"if", "int", "long", "register", "return", "short",
-						"signed", "sizeof", "static", "struct", "switch", "typedef",
-						"union", "unsigned", "void", "volatile", "while" };
+						  "continue", "default", "do", "double", "else",
+						  "enum", "extern", "float", "for", "goto",
+						  "if", "include", "int", "long", "main",
+						  "NULL", "register", "return", "short", "signed",
+						  "sizeof", "static", "struct", "switch", "typedef",
+						  "union", "unsigned", "void", "volatile", "while" };
 			
 		public FilterC ()
 		{
