@@ -51,8 +51,10 @@ namespace Beagle.Tile {
 					Template["action:"] = "action:" + UniqueKey + "!";
 
 					if (this.Uri != null && this.Query != null) {
+						SnippetRequest req = new SnippetRequest (this.Query.StemmedText, this.Hit);
 						try {
-							Template["Snippet"] = this.Query.GetSnippet (this.Uri);
+							SnippetResponse response = (SnippetResponse) req.Send ();
+							Template["Snippet"] = response.Snippet;
 						} catch { }
 					}
 				}
