@@ -70,16 +70,15 @@ class ExtractContentTool {
 
 		Console.WriteLine ("Filename: " + indexable.Uri);
 
-		if (indexable.MimeType != null)
-			Console.WriteLine ("MimeType: " + indexable.MimeType);
-
 		Filter filter;
 
 		if (! FilterFactory.FilterIndexable (indexable, out filter))
-			Console.WriteLine ("No filter!");
+			Console.WriteLine ("No filter for {0}", indexable.MimeType);
 
-		if (filter != null)
+		if (filter != null) {
 			Console.WriteLine ("Filter: {0}", filter);
+			Console.WriteLine ("MimeType: {0}", filter.MimeType);
+		}
 
 		Console.WriteLine ();
 
@@ -92,10 +91,14 @@ class ExtractContentTool {
 			Console.WriteLine ();
 		}
 
-		bool first;
+		// Make sure that the properties are sorted.
+		ArrayList prop_array = new ArrayList (indexable.Properties);
+		prop_array.Sort ();
 
+		bool first;
 		first = true;
-		foreach (Beagle.Property prop in indexable.Properties) {
+
+		foreach (Beagle.Property prop in prop_array) {
 			if (first) {
 				Console.WriteLine ("Properties:");
 				first = false;
@@ -164,17 +167,19 @@ class ExtractContentTool {
 		Console.WriteLine ("Usage: beagle-extract-content [OPTIONS] file [file ...]");
 		Console.WriteLine ();
 		Console.WriteLine ("Options:");
+		Console.WriteLine ("  --debug\t\t\tPrint debug info to the console");
 		Console.WriteLine ("  --tokenize\t\t\tTokenize the text before printing");
 		Console.WriteLine ("  --show-children\t\tShow filtering information for items created by filters");
 		Console.WriteLine ("  --mimetype=<mime_type>\tUse filter for mime_type");
+		Console.WriteLine ("  --outfile=<filename>\t\tOutput file name");
 		Console.WriteLine ("  --help\t\t\tShow this message");
 		Console.WriteLine ();
 	}
 
 	static int Main (string[] args)
 	{
-		Logger.DefaultEcho = true;
-		Logger.DefaultLevel = LogLevel.Debug;
+		if (Array.IndexOf (args, "--debug") == -1)
+			Log.Disable ();
 
 		if (Array.IndexOf (args, "--help") != -1) {
 			PrintUsage ();
@@ -187,12 +192,23 @@ class ExtractContentTool {
 		if (Array.IndexOf (args, "--show-children") != -1)
 			show_children = true;
 
+		StreamWriter writer = null;
+		string outfile = null;
 		foreach (string arg in args) {
 
 			// mime-type option
 			if (arg.StartsWith ("--mimetype=")) {
 				mime_type = arg.Substring (11);    
 				continue;
+			// output file option
+			// we need this in case the output contains different encoding
+			// printing to Console might not always display properly
+			} else if (arg.StartsWith ("--outfile=")) {
+				outfile = arg.Substring (10);    
+				Console.WriteLine ("Redirecting output to " + outfile);
+				FileStream f = new FileStream (outfile, FileMode.Create);
+				writer = new StreamWriter (f, System.Text.Encoding.UTF8);
+				continue;
 			} else if (arg.StartsWith ("--")) // option, skip it 
 				continue;
 			
@@ -202,12 +218,28 @@ class ExtractContentTool {
 				indexable.MimeType = mime_type;
 
 			try {
+				if (writer != null) {
+					Console.SetOut (writer);
+				}
+
 				Display (indexable);
+				if (writer != null) {
+					writer.Flush ();
+				}
+				
+				if (outfile != null) {
+					StreamWriter standardOutput = new StreamWriter(Console.OpenStandardOutput());
+					standardOutput.AutoFlush = true;
+					Console.SetOut(standardOutput);
+				}
+				
 			} catch (Exception e) {
 				Console.WriteLine ("Unable to filter {0}: {1}", uri, e.Message);
 				return -1;
 			}
 		}
+		if (writer != null)
+			writer.Close ();
 
 		return 0;
 	}
