@@ -52,36 +52,17 @@ namespace Beagle.Daemon {
 
 		//////////////////////////
 
-		private bool delete_content;
-
-		public bool DeleteContent {
-			get { return this.delete_content; }
-			set { this.delete_content = value; }
-		}
-
-		//////////////////////////
-
-		private   ArrayList supported_mime_types = new ArrayList ();
-		private   ArrayList supported_extensions = new ArrayList ();
+		private ArrayList supported_flavors = new ArrayList ();
 		
-		protected void AddSupportedMimeType (string mime_type)
+		protected void AddSupportedFlavor (FilterFlavor flavor) 
 		{
-			supported_mime_types.Add (mime_type);
+			supported_flavors.Add (flavor);
 		}
 
-		protected void AddSupportedExtension (string extension)
-		{
-			supported_extensions.Add (extension);
+		public ICollection SupportedFlavors {
+			get { return supported_flavors; }
 		}
-
-		public IEnumerable SupportedMimeTypes {
-			get { return supported_mime_types; }
-		}
-
-		public IEnumerable SupportedExtensions {
-			get { return supported_extensions; }
-		}
-
+		
 		//////////////////////////
 
 		// Filters are versioned.  This allows us to automatically re-index
@@ -114,6 +95,8 @@ namespace Beagle.Daemon {
 			version = v;
 		}
 
+		
+
 		//////////////////////////
 
 		private string this_mime_type = null;
@@ -205,11 +188,6 @@ namespace Beagle.Daemon {
 		private ArrayList hotPool;
 		private ArrayList propertyPool;
 		
-		private int max_text_pool_len = 0;
-		private int max_text_pool_size = 0;
-		private int max_hot_pool_len = 0;
-		
-
 		private bool last_was_structural_break = true;
 
 		// This two-arg AppendText() will give flexibility to
@@ -230,19 +208,21 @@ namespace Beagle.Daemon {
 		public void AppendText (string str, string strHot)
 		{
 			if (!IsFrozen && str != null && str != "") {
-				
-				// FIXME: Do we need to handle '\n' in any 
-				// other way?
 				int i = 0;
-				string line;
-				string[] lines = str.Split ('\n');
-				for (i = 0; i < lines.Length; i++) {
-					line = lines[i].Trim();
-					if (line.Length > 0) {
-						ReallyAppendText (line, null);
-						AppendStructuralBreak ();
+				string[] lines;
+
+				// Avoid unnecessary allocation of a string
+				// FIXME: Handle \r, \r\n cases.
+				if (str.IndexOf ('\n') > -1) {
+					lines = str.Split ('\n'); 
+					foreach (string line in lines) {
+						if (line.Length > 0) {
+							ReallyAppendText (line, null);
+							AppendStructuralBreak ();
+						}
 					}
-				}
+				} else 
+					ReallyAppendText (str, null);
 			}
 			ReallyAppendText (null, strHot);
 		}
@@ -263,19 +243,6 @@ namespace Beagle.Daemon {
 			if (str != null) {
 				textPool.Add (str);
 
-				int pool_size = 0;
-				foreach (string x in textPool)
-					pool_size += x.Length;
-
-				if (pool_size > max_text_pool_size)
-					max_text_pool_size = pool_size;
-
-				if (textPool.Count > max_text_pool_len)
-					max_text_pool_len = textPool.Count;
-
-				if (hotPool.Count > max_hot_pool_len)
-					max_hot_pool_len = hotPool.Count;
-
 				if (snippetWriter != null)
 					snippetWriter.Write (str);
 
@@ -340,10 +307,31 @@ namespace Beagle.Daemon {
 			isFinished = true;
 		}
 
+		private bool has_error = false;
+
+		public bool HasError {
+			get { return has_error; }
+		}
+
+		protected void Error ()
+		{
+			Cleanup (); // force the clean-up of temporary files on an error
+			has_error = true;
+		}
+
 		//////////////////////////
 
+		protected virtual void DoOpen (FileSystemInfo info) {
+			if (info is FileInfo)
+				DoOpen (info as FileInfo);
+			else if (info is DirectoryInfo)
+				DoOpen (info as DirectoryInfo);
+		}
+
 		protected virtual void DoOpen (FileInfo info) { }
 
+		protected virtual void DoOpen (DirectoryInfo info) { }
+
 		protected virtual void DoPullProperties () { }
 
 		protected virtual void DoPullSetup () { }
@@ -369,30 +357,78 @@ namespace Beagle.Daemon {
 		*/
 
 		private string tempFile = null;
-		private FileInfo currentInfo = null;
+		private FileSystemInfo currentInfo = null;
 		private FileStream currentStream = null;
 		private StreamReader currentReader = null;
 
-		public void Open (Stream stream)
+		public bool Open (TextReader reader)
 		{
-			// If we are handed a stream, dump it into
-			// a temporary file.
-			tempFile = Path.GetTempFileName();
-			Stream tempStream = File.OpenWrite (tempFile);
+			tempFile = Path.GetTempFileName ();
+                        FileStream file_stream = File.OpenWrite (tempFile);
 
-			const int BUFFER_SIZE = 8192;
-			byte[] buffer = new byte [BUFFER_SIZE];
-			int n;
-			while ((n = stream.Read (buffer, 0, BUFFER_SIZE)) > 0) {
-				tempStream.Write (buffer, 0, n);
-			}
+			//Logger.Log.Debug ("Storing text in tempFile {0}", tempFile);
 
-			tempStream.Close ();
+                        // When we dump the contents of a reader into a file, we
+                        // expect to use it again soon.
+                        FileAdvise.PreLoad (file_stream);
 
-			Open (new FileInfo (tempFile));
+                        // Make sure the temporary file is only readable by the owner.
+                        // FIXME: There is probably a race here.  Could some malicious program
+                        // do something to the file between creation and the chmod?
+                        Mono.Unix.Native.Syscall.chmod (tempFile, (Mono.Unix.Native.FilePermissions) 256);
+
+                        BufferedStream buffered_stream = new BufferedStream (file_stream);
+                        StreamWriter writer = new StreamWriter (buffered_stream);
+
+                        const int BUFFER_SIZE = 8192;
+                        char [] buffer = new char [BUFFER_SIZE];
+
+                        int read;
+                        do {
+                                read = reader.Read (buffer, 0, BUFFER_SIZE);
+                                if (read > 0)
+                                        writer.Write (buffer, 0, read);
+                        } while (read > 0);
+
+                        writer.Close ();
+
+			return Open (new FileInfo (tempFile));
+		}
+		
+		public bool Open (Stream stream)
+		{
+			tempFile = Path.GetTempFileName ();
+                        FileStream file_stream = File.OpenWrite (tempFile);
+			
+			//Logger.Log.Debug ("Storing stream in tempFile {0}", tempFile);
+
+                        // When we dump the contents of a reader into a file, we
+                        // expect to use it again soon.
+                        FileAdvise.PreLoad (file_stream);
+
+                        // Make sure the temporary file is only readable by the owner.
+                        // FIXME: There is probably a race here.  Could some malicious program
+                        // do something to the file between creation and the chmod?
+                        Mono.Unix.Native.Syscall.chmod (tempFile, (Mono.Unix.Native.FilePermissions) 256);
+
+                        BufferedStream buffered_stream = new BufferedStream (file_stream);
+
+                        const int BUFFER_SIZE = 8192;
+                        byte [] buffer = new byte [BUFFER_SIZE];
+
+                        int read;
+                        do {
+                                read = stream.Read (buffer, 0, BUFFER_SIZE);
+                                if (read > 0)
+                                        buffered_stream.Write (buffer, 0, read);
+                        } while (read > 0);
+
+                        buffered_stream.Close ();
+
+			return Open (new FileInfo (tempFile));
 		}
 
-		public void Open (FileInfo info)
+		public bool Open (FileSystemInfo info)
 		{
 			isFinished = false;
 			textPool = new ArrayList ();
@@ -401,55 +437,75 @@ namespace Beagle.Daemon {
 
 			currentInfo = info;
 
-			// Open a stream for this file.
-			currentStream = new FileStream (info.FullName,
-							FileMode.Open,
-							FileAccess.Read,
-							FileShare.Read);
-
-			// Our default assumption is sequential reads.
-			// FIXME: Is this the right thing to do here?
-			FileAdvise.IncreaseReadAhead (currentStream);
-
-			// Give the OS a hint that we will be reading this
-			// file soon.
-			FileAdvise.PreLoad (currentStream);			
+			if (info is FileInfo) {
+				// Open a stream for this file.
+				currentStream = new FileStream (info.FullName,
+								FileMode.Open,
+								FileAccess.Read,
+								FileShare.Read);
+				
+				// Our default assumption is sequential reads.
+				// FIXME: Is this the right thing to do here?
+				FileAdvise.IncreaseReadAhead (currentStream);
+				
+				// Give the OS a hint that we will be reading this
+				// file soon.
+				FileAdvise.PreLoad (currentStream);				
+			}
 
 			try {
 				DoOpen (info);
+
+				if (IsFinished)
+					return true;
+				else if (HasError)
+					return false;
+				
+				DoPullProperties ();
+				
+				if (IsFinished) 
+					return true;
+				else if (HasError)
+					return false;
+				
+				// Close and reset our TextReader
+				if (currentReader != null) {
+					currentReader.Close ();
+					currentReader = null;
+				}
+				
+				// Seek back to the beginning of our stream
+				currentStream.Seek (0, SeekOrigin.Begin);
+				
+				DoPullSetup ();
+				
+				if (HasError)
+					return false;				
 			} catch (Exception e) {
 				Logger.Log.Warn ("Unable to filter {0}: {1}", info.FullName, e.Message);
-				return;
-			}
-				
-			if (IsFinished)
-				return;
-			
-			DoPullProperties ();
-			if (IsFinished) 
-				return;
-			
-			// Close and reset our TextReader
-			if (currentReader != null) {
-				currentReader.Close ();
-				currentReader = null;
+				Cleanup (); // clean up temporary files on an exception
+				return false;
 			}
 
-			// Seek back to the beginning of our stream
-			currentStream.Seek (0, SeekOrigin.Begin);
-
-			DoPullSetup ();
-			if (IsFinished)
-				return;
+			return true;
 		}
 
-		public void Open (string path)
+		public bool Open (string path)
 		{
-			Open (new FileInfo (path));
+			if (File.Exists (path))
+				return Open (new FileInfo (path));
+			else if (Directory.Exists (path))
+				 return Open (new DirectoryInfo (path));
+			else 
+				return false;
 		}
 
 		public FileInfo FileInfo {
-			get { return currentInfo; }
+			get { return currentInfo as FileInfo; }
+		}
+
+		public DirectoryInfo DirectoryInfo {
+			get { return currentInfo as DirectoryInfo; }
 		}
 
 		public Stream Stream {
@@ -481,6 +537,8 @@ namespace Beagle.Daemon {
 
 		private void Close ()
 		{
+			Cleanup ();
+
 			if (currentStream == null)
 				return;
 
@@ -499,53 +557,55 @@ namespace Beagle.Daemon {
 
 			if (snippetWriter != null)
 				snippetWriter.Close ();
+		}
 
-			if (tempFile != null)
-				File.Delete (tempFile);
-
-			if (currentInfo != null && this.DeleteContent) {
+		public void Cleanup ()
+		{
+			if (tempFile != null) {
 				try {
-					currentInfo.Delete ();
-				} catch (Exception e) {
-					Logger.Log.Debug ("Caught exception trying to delete {0} in filter '{1}'",
-							  currentInfo.FullName, Name);
-					Logger.Log.Debug (e);					
+					File.Delete (tempFile);
+				} catch (Exception ex) {
+					// Just in case it is gone already
 				}
+				tempFile = null;
 			}
 		}
 
-		private string PullFromArray (ArrayList array)
+		private bool PullFromArray (ArrayList array, StringBuilder sb)
 		{
 			while (array.Count == 0 && Pull ()) { }
+
 			if (array.Count > 0) {
-				string str = (string) array [0];
-				array.RemoveAt (0);
-				return str;
+				foreach (string str in array)
+					sb.Append (str);
+
+				array.Clear ();
+				return true;
 			}
-			return null;
+			return false;
 		}
 
-		private string PullTextCarefully (ArrayList array)
+		private bool PullTextCarefully (ArrayList array, StringBuilder sb)
 		{
-			string text = null;
-			try {	
-				text = PullFromArray (array);
+			bool pulled = false;
+			try {
+				pulled = PullFromArray (array, sb);
 			} catch (Exception ex) {
 				Logger.Log.Debug ("Caught exception while pulling text in filter '{0}'", Name);
 				Logger.Log.Debug (ex);
 			}
-			return text;
 
+			return pulled;
 		}
 
-		private string PullText ()
+		private bool PullText (StringBuilder sb)
 		{
-			return PullTextCarefully (textPool);
+			return PullTextCarefully (textPool, sb);
 		}
 
-		private string PullHotText ()
+		private bool PullHotText (StringBuilder sb)
 		{
-			return PullTextCarefully (hotPool);
+			return PullTextCarefully (hotPool, sb);
 		}
 
 		public TextReader GetTextReader ()
@@ -563,5 +623,36 @@ namespace Beagle.Daemon {
 		public IEnumerable Properties {
 			get { return propertyPool; }
 		}
+
+		//////////////////////////////
+
+		// This is used primarily for the generation of URIs for the
+		// child indexables that can be created as a result of the
+		// filtering process.
+
+		private Uri uri = null;
+
+		public Uri Uri {
+			get { return uri; }
+			set { uri = value; }
+		}
+
+		//////////////////////////////
+
+		private ArrayList child_indexables = new ArrayList ();
+
+		protected void AddChildIndexable (Indexable indexable)
+		{
+			this.child_indexables.Add (indexable);
+		}
+		
+		protected void AddChildIndexables (ICollection indexables)
+		{
+			this.child_indexables.AddRange (indexables);
+		}
+
+		public ArrayList ChildIndexables {
+			get { return this.child_indexables; }
+		}
 	}
 }
